@@ -2,6 +2,8 @@
 #ifndef _GLIBMM_ARRAYHANDLE_H
 #define _GLIBMM_ARRAYHANDLE_H
 
+/* $Id$ */
+
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
@@ -19,9 +21,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glibmmconfig.h>
 #include <glibmm/containerhandle_shared.h>
 
+
 namespace Glib
 {
 
@@ -65,21 +67,6 @@ typename Tr::CType* create_array(For pbegin, size_t size, Tr)
   return array;
 }
 
-template <class For>
-gboolean* create_bool_array(For pbegin, size_t size)
-{
-  gboolean *const array(static_cast<gboolean*>(g_malloc((size + 1) * sizeof(gboolean))));
-  gboolean *const array_end(array + size);
-
-  for(gboolean* pdest(array); pdest != array_end; ++pdest)
-  {
-    *pdest = *pbegin;
-    ++pbegin;
-  }
-
-  *array_end = false;
-  return array;
-}
 
 /* Convert from any container that supports forward
  * iterators and has a size() method.
@@ -98,20 +85,6 @@ struct ArraySourceTraits
   static const Glib::OwnershipType initial_ownership = Glib::OWNERSHIP_SHALLOW;
 };
 
-// source traits for bools.
-template <class Cont>
-struct BoolArraySourceTraits
-{
-  typedef gboolean CType;
-
-  static size_t get_size(const Cont& cont)
-    { return cont.size(); }
-
-  static const CType* get_data(const Cont& cont, size_t size)
-    { return Glib::Container_Helpers::create_bool_array(cont.begin(), size); }
-
-  static const Glib::OwnershipType initial_ownership = Glib::OWNERSHIP_SHALLOW;
-};
 /* Convert from a 0-terminated array.  The Cont argument must be a pointer
  * to the first element.  Note that only arrays of the C type are supported.
  */
@@ -182,9 +155,6 @@ public:
 
   inline ArrayHandleIterator<Tr> &     operator++();
   inline const ArrayHandleIterator<Tr> operator++(int);
-  // these are needed by msvc 2005 when using deque.
-  inline ArrayHandleIterator<Tr> &     operator--();
-  inline const ArrayHandleIterator<Tr> operator--(int);
 
   // All this random access stuff is only there because STL algorithms
   // usually have optimized specializations for random access iterators,
@@ -210,13 +180,8 @@ private:
 } // namespace Container_Helpers
 
 
-/** This is an intermediate type. When a method takes this, or returns this, you
- * should use a standard C++ container of your choice, such as std::list or
- * std::vector.
- *
- * However, this is not used in new API. We now prefer to just use std::vector,
- * which is less flexibile, but makes the API clearer.
- *
+/** If a method takes this as an argument, or has this as a return type, then you can use a standard
+ * container such as std::list or std::vector.
  * @ingroup ContHandles
  */
 template < class T, class Tr = Glib::Container_Helpers::TypeTraits<T> >
@@ -271,102 +236,8 @@ private:
   ArrayHandle<T, Tr>& operator=(const ArrayHandle<T,Tr>&);
 };
 
-template<>
-class ArrayHandle<bool, Container_Helpers::TypeTraits<bool> >
-{
-public:
-  typedef ArrayHandle<bool, Container_Helpers::TypeTraits<bool> > Me;
-  typedef Container_Helpers::TypeTraits<bool>      Tr;
-
-  typedef Tr::CppType  CppType;
-  typedef Tr::CType    CType;
-
-  typedef CppType               value_type;
-  typedef size_t                size_type;
-  typedef ptrdiff_t             difference_type;
-
-  typedef Glib::Container_Helpers::ArrayHandleIterator<Tr>   const_iterator;
-  typedef Glib::Container_Helpers::ArrayHandleIterator<Tr>   iterator;
-
-  template <class Cont> inline
-    ArrayHandle(const Cont& container);
-
-  // Take over ownership of an array created by GTK+ functions.
-  inline ArrayHandle(const CType* array, size_t array_size, Glib::OwnershipType ownership);
-  inline ArrayHandle(const CType* array, Glib::OwnershipType ownership);
-
-  // Copying clears the ownership flag of the source handle.
-  inline ArrayHandle(const Me& other);
-
-  ~ArrayHandle();
-
-  inline const_iterator begin() const;
-  inline const_iterator end()   const;
-
-  // this is inside class definition, so msvc 2005, 2008 and 2010 can compile this code.
-  template <class U> inline operator std::vector<U>() const
-  {
-#ifdef GLIBMM_HAVE_TEMPLATE_SEQUENCE_CTORS
-    return std::vector<U>(this->begin(), this->end());
-#else
-    std::vector<U> temp;
-    temp.reserve(this->size());
-    Glib::Container_Helpers::fill_container(temp, this->begin(), this->end());
-    return temp;
-#endif
-  }
-
-  // this is inside class definition, so msvc 2005, 2008 and 2010 can compile this code.
-  template <class U> inline operator std::deque<U>() const
-  {
-#ifdef GLIBMM_HAVE_TEMPLATE_SEQUENCE_CTORS
-    return std::deque<U>(this->begin(), this->end());
-#else
-    std::deque<U> temp;
-    Glib::Container_Helpers::fill_container(temp, this->begin(), this->end());
-    return temp;
-#endif
-  }
-
-  // this is inside class definition, so msvc 2005, 2008 and 2010 can compile this code.
-  template <class U> inline operator std::list<U>() const
-  {
-#ifdef GLIBMM_HAVE_TEMPLATE_SEQUENCE_CTORS
-    return std::list<U>(this->begin(), this->end());
-#else
-    std::list<U> temp;
-    Glib::Container_Helpers::fill_container(temp, this->begin(), this->end());
-    return temp;
-#endif
-  }
-
-  template <class Cont> inline
-    void assign_to(Cont& container) const;
-
-  template <class Out> inline
-    void copy(Out pdest) const;
-
-  inline const CType* data()  const;
-  inline size_t       size()  const;
-  inline bool         empty() const;
-
-private:
-  size_t                      size_;
-  const CType*                parray_;
-  mutable Glib::OwnershipType ownership_;
-
-  // No copy assignment.
-  Me& operator=(const Me&);
-};
-
-//TODO: Remove this when we can break glibmm API.
 /** If a method takes this as an argument, or has this as a return type, then you can use a standard
  * container such as std::list<Glib::ustring> or std::vector<Glib::ustring>.
- *
- *
- * However, this is not used in new API. We now prefer to just use std::vector,
- * which is less flexibile, but makes the API clearer.
- *
  * @ingroup ContHandles
  */
 typedef ArrayHandle<Glib::ustring> StringArrayHandle;
@@ -415,19 +286,6 @@ const ArrayHandleIterator<Tr> ArrayHandleIterator<Tr>::operator++(int)
   return ArrayHandleIterator<Tr>(pos_++);
 }
 
-template <class Tr> inline
-ArrayHandleIterator<Tr>& ArrayHandleIterator<Tr>::operator--()
-{
-  --pos_;
-  return *this;
-}
-
-template <class Tr> inline
-const ArrayHandleIterator<Tr> ArrayHandleIterator<Tr>::operator--(int)
-{
-  return ArrayHandleIterator<Tr>(pos_--);
-}
-
 template <class Tr> inline
 ArrayHandleIterator<Tr>&
 ArrayHandleIterator<Tr>::operator+=(typename ArrayHandleIterator<Tr>::difference_type rhs)
@@ -520,7 +378,7 @@ template <class T, class Tr> inline
 ArrayHandle<T,Tr>::ArrayHandle(const typename ArrayHandle<T,Tr>::CType* array, size_t array_size,
                                Glib::OwnershipType ownership)
 :
-  size_      ((array) ? array_size : 0),
+  size_      (array_size),
   parray_    (array),
   ownership_ (ownership)
 {}
@@ -547,7 +405,7 @@ ArrayHandle<T,Tr>::ArrayHandle(const ArrayHandle<T,Tr>& other)
 template <class T, class Tr>
 ArrayHandle<T,Tr>::~ArrayHandle()
 {
-  if(parray_ && ownership_ != Glib::OWNERSHIP_NONE)
+  if(ownership_ != Glib::OWNERSHIP_NONE)
   {
     if(ownership_ != Glib::OWNERSHIP_SHALLOW)
     {
@@ -655,96 +513,6 @@ bool ArrayHandle<T,Tr>::empty() const
   return (size_ == 0);
 }
 
-
-/**** Glib::ArrayHandle<bool> **********************************************/
-
-template <class Cont>
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::ArrayHandle(const Cont& container)
-:
-  size_      (Glib::Container_Helpers::BoolArraySourceTraits<Cont>::get_size(container)),
-  parray_    (Glib::Container_Helpers::BoolArraySourceTraits<Cont>::get_data(container, size_)),
-  ownership_ (Glib::Container_Helpers::BoolArraySourceTraits<Cont>::initial_ownership)
-{}
-
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::ArrayHandle(const gboolean* array, size_t array_size,
-                                                                    Glib::OwnershipType ownership)
-:
-  size_      ((array) ? array_size : 0),
-  parray_    (array),
-  ownership_ (ownership)
-{}
-
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::ArrayHandle(const gboolean* array,
-                                                                    Glib::OwnershipType ownership)
-:
-  size_      ((array) ? Glib::Container_Helpers::compute_array_size(array) : 0),
-  parray_    (array),
-  ownership_ (ownership)
-{}
-
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::ArrayHandle(const ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >& other)
-:
-  size_      (other.size_),
-  parray_    (other.parray_),
-  ownership_ (other.ownership_)
-{
-  other.ownership_ = Glib::OWNERSHIP_NONE;
-}
-
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::const_iterator ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::begin() const
-{
-  return Glib::Container_Helpers::ArrayHandleIterator<Tr>(parray_);
-}
-
-inline
-ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::const_iterator ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::end() const
-{
-  return Glib::Container_Helpers::ArrayHandleIterator<Tr>(parray_ + size_);
-}
-
-template <class Cont>
-inline
-void ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::assign_to(Cont& container) const
-{
-#ifdef GLIBMM_HAVE_TEMPLATE_SEQUENCE_CTORS
-  container.assign(this->begin(), this->end());
-#else
-  Cont temp;
-  Glib::Container_Helpers::fill_container(temp, this->begin(), this->end());
-  container.swap(temp);
-#endif
-}
-
-template <class Out>
-inline
-void ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::copy(Out pdest) const
-{
-  std::copy(this->begin(), this->end(), pdest);
-}
-
-inline
-const gboolean* ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::data() const
-{
-  return parray_;
-}
-
-inline
-size_t ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::size() const
-{
-  return size_;
-}
-
-inline
-bool ArrayHandle<bool,Container_Helpers::TypeTraits<bool> >::empty() const
-{
-  return (size_ == 0);
-}
-
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 } // namespace Glib
