@@ -1,29 +1,30 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_PROPERTYPROXY_H
 #define _GLIBMM_PROPERTYPROXY_H
-/* $Id: propertyproxy.h,v 1.4 2005/06/08 16:06:13 murrayc Exp $ */
+/* $Id$ */
 
 /* propertyproxy.h
  *
  * Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #include <glibmm/propertyproxy_base.h>
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
 
 namespace Glib
 {
@@ -38,6 +39,11 @@ namespace Glib
  * @endcode
  *
  * You may also receive notification when a property's value changes, by connecting to signal_changed().
+ *
+ * You may register new properties for your class (actually for the underlying GType) 
+ * simply by adding a PropertyProxy instance as a class member.
+ * However, your constructor must call the Glib::ObjectBase constructor with a new GType name, 
+ * in order to register a new GType.
  */
 template <class T>
 class PropertyProxy : public PropertyProxy_Base
@@ -174,6 +180,7 @@ T PropertyProxy_ReadOnly<T>::get_value() const
 
 } // namespace Glib
 
+#endif //GLIBMM_PROPERTIES_ENABLED
 
 #endif /* _GLIBMM_PROPERTYPROXY_H */
 
